camelot.camelot.model.authentication.PartyContactMechanism

Package camelot :: Package camelot :: Package model :: Module authentication :: Class PartyContactMechanism |
[hide private]
[frames] | no frames]

# Class PartyContactMechanism

source code

Nested Classes | [hide private]
| Admin

Instance Methods | [hide private]
__unicode__(self) | source code

Class Variables | [hide private]
| party = `ManyToOne('Party', required= True, ondelete= 'cascade'`...``
| contact_mechanism = `ManyToOne('ContactMechanism', required= Tr`...``
| from_date = `Field(Date(), default= datetime.date.today, requir`...``
| thru_date = `Field(Date(), default= end_of_times, index= True)`
| comment = `Field(Unicode(256))`

Class Variable Details | [hide private]

  ### party Value:
      ManyToOne('Party', required= True, ondelete= 'cascade', onupdate= 'cas
      cade')

  ### contact_mechanism Value:
      ManyToOne('ContactMechanism', required= True, ondelete= 'cascade', onu
      pdate= 'cascade')

  ### from_date Value:
      Field(Date(), default= datetime.date.today, required= True, index= Tru
      e)